Package: MSstatsConvert
Title: Import Data from Various Mass Spectrometry Signal Processing
        Tools to MSstats Format
Version: 1.22.1
Authors@R: c(
  person("Mateusz", "Staniak", email = "mtst@mstaniak.pl", role = "aut"),
  person("Devon", "Kohler", email = "kohler.d@northeastern.edu", role = "aut"),
  person("Anthony", "Wu", email = "wu.anthon@northeastern.edu", role = c("aut", "cre")),
  person("Meena", "Choi", email = "mnchoi67@gmail.com", role = "aut"),
  person("Ting", "Huang", email = "thuang0703@gmail.com", role = "aut"),
  person("Olga", "Vitek", , email = "o.vitek@northeastern.edu", role = "aut")) 
Description: MSstatsConvert provides tools for importing reports of Mass Spectrometry data processing tools
    into R format suitable for statistical analysis using the MSstats and MSstatsTMT packages.
License: Artistic-2.0
Encoding: UTF-8
Roxygen: list(markdown = TRUE)
RoxygenNote: 7.3.3
biocViews: MassSpectrometry, Proteomics, Software, DataImport,
        QualityControl
Depends: R (>= 4.0)
Imports: data.table, methods, checkmate, utils, stringi, Rcpp, parallel
Suggests: tinytest, covr, knitr, arrow, rmarkdown
LinkingTo: Rcpp
Collate: 'clean_ProteinProspector.R' 'clean_Metamorpheus.R'
        'clean_DIANN.R' 'clean_Philosopher.R' 'clean_Spectronaut.R'
        'clean_SpectroMine.R' 'clean_Skyline.R'
        'clean_ProteomeDiscoverer.R' 'clean_Progenesis.R'
        'clean_OpenSWATH.R' 'clean_OpenMS.R' 'clean_MaxQuant.R'
        'clean_DIAUmpire.R' 'MSstatsConvert_core_functions.R'
        'RcppExports.R' 'converters_DIANNtoMSstatsFormat.R'
        'converters_DIAUmpiretoMSstatsFormat.R'
        'converters_FragPipetoMSstatsFormat.R'
        'converters_MaxQtoMSstatsFormat.R'
        'converters_MaxQtoMSstatsTMTFormat.R'
        'converters_MetamorpheusToMSstatsFormat.R'
        'converters_OpenMStoMSstatsFormat.R'
        'converters_OpenMStoMSstatsTMTFormat.R'
        'converters_OpenSWATHtoMSstatsFormat.R'
        'converters_PDtoMSstatsFormat.R'
        'converters_PDtoMSstatsTMTFormat.R'
        'converters_PhilosophertoMSstatsTMTFormat.R'
        'converters_ProgenesistoMSstatsFormat.R'
        'converters_ProteinProspectortoMSstatsTMTFormat.R'
        'converters_SkylinetoMSstatsFormat.R'
        'converters_SpectroMinetoMSstatsTMTFormat.R'
        'converters_SpectronauttoMSstatsFormat.R'
        'utils_MSstatsConvert.R' 'utils_annotation.R'
        'utils_anomaly_score.R' 'utils_balanced_design.R'
        'utils_checks.R' 'utils_classes.R' 'utils_clean_features.R'
        'utils_data_health.R' 'utils_documentation.R'
        'utils_dt_operations.R' 'utils_filtering.R' 'utils_fractions.R'
        'utils_logging.R' 'utils_shared_peptides.R'
VignetteBuilder: knitr
git_url: https://git.bioconductor.org/packages/MSstatsConvert
git_branch: RELEASE_3_23
git_last_commit: fe449ec
git_last_commit_date: 2026-07-16
Repository: Bioconductor 3.23
Date/Publication: 2026-07-19
NeedsCompilation: yes
Packaged: 2026-07-19 23:12:23 UTC; biocbuild
Author: Mateusz Staniak [aut],
  Devon Kohler [aut],
  Anthony Wu [aut, cre],
  Meena Choi [aut],
  Ting Huang [aut],
  Olga Vitek [aut]
Maintainer: Anthony Wu <wu.anthon@northeastern.edu>
