# Generated by roxygen2: do not edit by hand

S3method(as.data.frame,MSstatsValidated)
S3method(as.data.table,MSstatsValidated)
export(CheckDataHealth)
export(DIANNtoMSstatsFormat)
export(DIAUmpiretoMSstatsFormat)
export(FragPipetoMSstatsFormat)
export(MSstatsAnomalyScores)
export(MSstatsBalancedDesign)
export(MSstatsClean)
export(MSstatsImport)
export(MSstatsLogsSettings)
export(MSstatsMakeAnnotation)
export(MSstatsPreprocess)
export(MSstatsSaveSessionInfo)
export(MaxQtoMSstatsFormat)
export(MaxQtoMSstatsTMTFormat)
export(MetamorpheusToMSstatsFormat)
export(OpenMStoMSstatsFormat)
export(OpenMStoMSstatsTMTFormat)
export(OpenSWATHtoMSstatsFormat)
export(PDtoMSstatsFormat)
export(PDtoMSstatsTMTFormat)
export(PhilosophertoMSstatsTMTFormat)
export(ProgenesistoMSstatsFormat)
export(ProteinProspectortoMSstatsTMTFormat)
export(SkylinetoMSstatsFormat)
export(SpectroMinetoMSstatsTMTFormat)
export(SpectronauttoMSstatsFormat)
export(getDataType)
export(getInputFile)
exportMethods(getDataType)
exportMethods(getInputFile)
import(Rcpp)
import(data.table)
import(parallel)
importFrom(data.table,as.data.table)
importFrom(data.table,fread)
importFrom(data.table,melt)
importFrom(data.table,rbindlist)
importFrom(data.table,setnames)
importFrom(data.table,uniqueN)
importFrom(methods,new)
importFrom(stats,na.omit)
importFrom(utils,sessionInfo)
useDynLib(MSstatsConvert, .registration = TRUE)
