% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils_dt_operations.R
\name{.fixColumnTypes}
\alias{.fixColumnTypes}
\title{Change classes of multiple columns}
\usage{
.fixColumnTypes(
  input,
  numeric_columns = NULL,
  character_columns = NULL,
  factor_columns = NULL
)
}
\arguments{
\item{input}{data.table preprocessed by one of the \verb{cleanRaw*} functions.}

\item{numeric_columns}{chr, vector of names of columns that will be
converted to numeric.}

\item{character_columns}{chr, vector of names of colums taht will be
converted to character.}

\item{factor_columns}{chr, vector of names of columns that will be
converted to factor.}
}
\value{
data.table
}
\description{
Change classes of multiple columns
}
\keyword{internal}
