% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils_balanced_design.R
\name{.getMissingRunsPerFeature}
\alias{.getMissingRunsPerFeature}
\title{Get names of missing runs}
\usage{
.getMissingRunsPerFeature(input)
}
\arguments{
\item{input}{output of \code{MSstatsPreprocess}}
}
\value{
data.table
}
\description{
Get names of missing runs
}
\keyword{internal}
