% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils_fractions.R
\name{.checkOverlappedFeatures}
\alias{.checkOverlappedFeatures}
\title{Check if any features are measured in multiple fractions}
\usage{
.checkOverlappedFeatures(input)
}
\arguments{
\item{input}{output of \code{MSstatsPreprocess}}
}
\value{
data.table
}
\description{
Check if any features are measured in multiple fractions
}
\keyword{internal}
