% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/clean_DIAUmpire.R
\name{.cleanRawDIAUmpire}
\alias{.cleanRawDIAUmpire}
\title{Clean raw DIAUmpire files}
\usage{
.cleanRawDIAUmpire(msstats_object, use_frag, use_pept)
}
\arguments{
\item{msstats_object}{Object that inherits from MSstatsInputFiles class.}

\item{use_frag}{TRUE will use the selected fragment for each peptide.
'Selected_fragments' column is required.}

\item{use_pept}{TRUE will use the selected fragment for each protein
'Selected_peptides' column is required.}
}
\value{
data.table
}
\description{
Clean raw DIAUmpire files
}
\keyword{internal}
