% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils_classes.R
\name{as.data.frame.MSstatsValidated}
\alias{as.data.frame.MSstatsValidated}
\title{Convert output of converters to data.frame}
\usage{
\method{as.data.frame}{MSstatsValidated}(x, ...)
}
\arguments{
\item{x}{object of class MSstatsValidated}

\item{...}{Additional arguments to be passed to or from other methods.}
}
\value{
data.frame
}
\description{
Convert output of converters to data.frame
}
