% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/MSstatsConvert_core_functions.R
\name{CheckDataHealth}
\alias{CheckDataHealth}
\title{Takes as input the output of the SpectronauttoMSstatsFormat function and calculates various quality metrics to assess the health of the data. Requires Anomaly Detection model to be fit.}
\usage{
CheckDataHealth(input)
}
\arguments{
\item{input}{MSstats input which is the output of Spectronaut converter}
}
\value{
list of two data.tables
}
\description{
Takes as input the output of the SpectronauttoMSstatsFormat function and calculates various quality metrics to assess the health of the data. Requires Anomaly Detection model to be fit.
}
