% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils_dt_operations.R
\name{.fixBasicColumns}
\alias{.fixBasicColumns}
\title{Remove underscores from sequences and change intensity type to numeric}
\usage{
.fixBasicColumns(input)
}
\arguments{
\item{input}{data.table}
}
\value{
data.table
}
\description{
Remove underscores from sequences and change intensity type to numeric
}
\keyword{internal}
