% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils_fractions.R
\name{.resolveFractionTies}
\alias{.resolveFractionTies}
\title{Resolve ties when multiple fractions share the maximum number of measurements
for a given feature. In the case of a tie, the fraction with the highest
mean intensity is selected.}
\usage{
.resolveFractionTies(input, max_fractions)
}
\arguments{
\item{input}{output of \code{MSstatsPreprocess}}

\item{max_fractions}{data.table of fractions that share the maximum number
of unique runs per feature, as produced by \code{.removeOverlappingFeatures}}
}
\value{
data.table with columns \code{feature} and \code{Fraction}, containing one
selected fraction per feature
}
\description{
Resolve ties when multiple fractions share the maximum number of measurements
for a given feature. In the case of a tie, the fraction with the highest
mean intensity is selected.
}
\keyword{internal}
