% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/clean_Skyline.R
\name{.handleIsotopicPeaks}
\alias{.handleIsotopicPeaks}
\title{Handle isotopic peaks}
\usage{
.handleIsotopicPeaks(input, aggregate = FALSE)
}
\arguments{
\item{input}{data.table preprocessed by one of the \verb{cleanRaw*} functions.}

\item{aggregate}{if TRUE, isotopic peaks will be summed.}
}
\value{
data.table
}
\description{
Handle isotopic peaks
}
\keyword{internal}
