% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils_clean_features.R
\name{.summarizeMultiplePSMs}
\alias{.summarizeMultiplePSMs}
\title{Pick one PSM from a data.table of several PSMs.}
\usage{
.summarizeMultiplePSMs(input, summary_function)
}
\arguments{
\item{input}{data.table preprocessed by one of the .cleanRaw* functions.}

\item{summary_function}{function that will be used to aggregate intensities
if needed.}
}
\value{
character - label of a chosen PSM
}
\description{
Pick one PSM from a data.table of several PSMs.
}
\keyword{internal}
