% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils_fractions.R
\name{.filterOverlapped}
\alias{.filterOverlapped}
\title{Remove overlapped features}
\usage{
.filterOverlapped(input, summary_function, overlapped_features)
}
\arguments{
\item{input}{data.table preprocessed by one of the .cleanRaw* functions and
merged with annotation.}

\item{summary_function}{summary function (mean, sum, max) that will be used
to pick one feature from multiple overlapping features}

\item{overlapped_features}{features that overlap.}
}
\value{
\code{data.table}
}
\description{
Remove overlapped features
}
\keyword{internal}
