% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils_clean_features.R
\name{.summarizeMultipleMeasurements}
\alias{.summarizeMultipleMeasurements}
\title{Summarize multiple measurements per feature in a single run}
\usage{
.summarizeMultipleMeasurements(
  input,
  aggregator,
  feature_columns,
  anomaly_metrics = c()
)
}
\arguments{
\item{input}{\code{data.table} pre-processed by one of the .cleanRaw* functions.}

\item{aggregator}{function that will be used to aggregate duplicated values.}

\item{feature_columns}{chr, vector of names of columns that define features.}

\item{anomaly_metrics}{character vector of quality metric column names
to be used as features in an anomaly detection model.}
}
\value{
\code{data.table}
}
\description{
Summarize multiple measurements per feature in a single run
}
\keyword{internal}
