% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils_dt_operations.R
\name{.standardizeColnames}
\alias{.standardizeColnames}
\title{Change column names to match read.table/read.csv/read.delim conventions}
\usage{
.standardizeColnames(col_names)
}
\arguments{
\item{col_names}{chr, vector of column names}
}
\value{
character vector
}
\description{
Change column names to match read.table/read.csv/read.delim conventions
}
\keyword{internal}
