% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils_fractions.R
\name{.removeOverlappingFeatures}
\alias{.removeOverlappingFeatures}
\title{Replace intensities of overlapped fractions with NA, keeping only one fraction}
\usage{
.removeOverlappingFeatures(input)
}
\arguments{
\item{input}{output of \code{MSstatsPreprocess}}
}
\value{
data.table
}
\description{
Replace intensities of overlapped fractions with NA, keeping only one fraction
}
\keyword{internal}
