% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils_balanced_design.R
\name{.getFullDesign}
\alias{.getFullDesign}
\title{Create a data.frame of each combination of values for given variables}
\usage{
.getFullDesign(input, group_col, feature_col, measurement_col, is_tmt)
}
\arguments{
\item{input}{output of \code{MSstatsPreprocess}}

\item{group_col}{name of column in \code{input}. Combination of values of
\code{feature_col} and \code{measurement_col} will be created within each unique value
of this column}

\item{is_tmt}{if TRUE, data will be treated as coming from TMT experiment.}

\item{`feature_col`}{name of the column that labels features}

\item{`measurement_col`}{name of a column with measurement labels - Runs in
label-free case, Channels in TMT case.}
}
\value{
data.table
}
\description{
Create a data.frame of each combination of values for given variables
}
\keyword{internal}
