% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils_logging.R
\name{.nullAppender}
\alias{.nullAppender}
\title{Appender used not to write messages}
\usage{
.nullAppender(level, ...)
}
\arguments{
\item{level}{log level}

\item{...}{messages - ignored}
}
\value{
NULL invisibly
}
\description{
A convenience function written to save time on checking if messages should
be printed or logs should be written to a file.
}
\keyword{internal}
