% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils_logging.R
\name{.fileAppender}
\alias{.fileAppender}
\title{File appender: returns a function(level, ...) that writes one line to a file}
\usage{
.fileAppender(log_file_path, append = TRUE)
}
\description{
File appender: returns a function(level, ...) that writes one line to a file
}
\keyword{internal}
