% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils_logging.R
\name{.logSuccess}
\alias{.logSuccess}
\title{Make a message about successful data cleaning/importing}
\usage{
.logSuccess(tool, event)
}
\arguments{
\item{tool}{name of a signal processing tool}
}
\value{
TRUE invisibly if logging was sucessful
}
\description{
Make a message about successful data cleaning/importing
}
\keyword{internal}
