% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils_MSstatsConvert.R
\docType{package}
\name{MSstatsConvert}
\alias{MSstatsConvert-package}
\alias{MSstatsConvert}
\title{MSstatsConvert: An R Package to Convert Data from Mass Spectrometry Signal Processing Tools to MSstats Format}
\description{
MSstatsConvert helps convert data from different types of mass spectrometry experiments and
signal processing tools to a format suitable for statistical analysis with the MSstats and MSstatsTMT packages.
}
\section{Main functions}{

\code{\link{MSstatsLogsSettings}} for logs management,
\code{\link{MSstatsImport}} for importing files created by signal processing tools,
\code{\link{MSstatsClean}} for re-formatting imported files into a consistent format,
\code{\link{MSstatsPreprocess}} for preprocessing cleaned files,
\code{\link{MSstatsBalancedDesign}} for handling fractions and creating balanced data.
}

\author{
\strong{Maintainer}: Anthony Wu \email{wu.anthon@northeastern.edu}

Authors:
\itemize{
  \item Mateusz Staniak \email{mtst@mstaniak.pl}
  \item Devon Kohler \email{kohler.d@northeastern.edu}
  \item Meena Choi \email{mnchoi67@gmail.com}
  \item Ting Huang \email{thuang0703@gmail.com}
  \item Olga Vitek \email{o.vitek@northeastern.edu}
}

}
\keyword{internal}
