% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils_fractions.R
\name{.countCommonFeatures}
\alias{.countCommonFeatures}
\title{Get common values from two vectors of features}
\usage{
.countCommonFeatures(features_1, features_2)
}
\arguments{
\item{features_1}{vector of feature names}

\item{features_2}{vector of feature_names}
}
\value{
character vector of common values of \code{features_1} and \code{features_2}
}
\description{
Get common values from two vectors of features
}
\keyword{internal}
