% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils_dt_operations.R
\name{.selectMSstatsColumns}
\alias{.selectMSstatsColumns}
\title{Select columns for MSstats format}
\usage{
.selectMSstatsColumns(input, anomaly_metrics)
}
\arguments{
\item{input}{data.table}
}
\value{
data.table
}
\description{
Select columns for MSstats format
}
\keyword{internal}
