% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils_fractions.R
\name{.handleFractionsTMT}
\alias{.handleFractionsTMT}
\title{Remove peptide ions overlapped among multiple fractions of the same biological mixture}
\usage{
.handleFractionsTMT(input)
}
\arguments{
\item{input}{data.table preprocessed by one of the .cleanRaw* functions and
merged with annotation.}
}
\value{
\code{data.table}
}
\description{
Remove peptide ions overlapped among multiple fractions of the same biological mixture
}
\keyword{internal}
