% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils_logging.R
\name{.makeScoreFilterMessage}
\alias{.makeScoreFilterMessage}
\title{Make a message about filtering based on a score}
\usage{
.makeScoreFilterMessage(
  score_column,
  score_threshold,
  direction,
  behavior,
  fill_value
)
}
\arguments{
\item{score_column}{chr, name of the column that contains scores.}

\item{score_threshold}{num, values below or above this threshold will be
removed from the data.}

\item{direction}{chr, if "greater" only values above the threshold will be
retained, if "smaller" - below the threshold.}

\item{behavior}{chr, if "remove", values below/above the threshold will be
removed, if "replace", they will be set to \code{fill_value}.}

\item{fill_value}{if \code{behavior} = "replace", values below/above the threshold
will be replaced with \code{fill_value}. Defaults to \code{NA}.}
}
\value{
character - message
}
\description{
Make a message about filtering based on a score
}
\keyword{internal}
