% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/clean_OpenSWATH.R
\name{.cleanRawOpenSWATH}
\alias{.cleanRawOpenSWATH}
\title{Clean raw OpenSWATH files}
\usage{
.cleanRawOpenSWATH(msstats_object)
}
\arguments{
\item{msstats_object}{an object of class \code{MSstatsSpectroMineFiles}.}
}
\value{
data.table
}
\description{
Clean raw OpenSWATH files
}
\keyword{internal}
