% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils_fractions.R
\name{.handleFractionsLF}
\alias{.handleFractionsLF}
\title{Handle overlapping features}
\usage{
.handleFractionsLF(input)
}
\arguments{
\item{input}{output of \code{MSstatsPreprocess}}
}
\value{
data.table
}
\description{
Handle overlapping features
}
\keyword{internal}
