% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/clean_SpectroMine.R
\name{.cleanRawSpectroMineTMT}
\alias{.cleanRawSpectroMineTMT}
\title{Clean raw SpectroMine TMT data}
\usage{
.cleanRawSpectroMineTMT(msstats_object)
}
\arguments{
\item{msstats_object}{an object of class \code{MSstatsSpectroMineFiles}.}
}
\value{
\code{data.table}
}
\description{
Clean raw SpectroMine TMT data
}
\keyword{internal}
