% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils_shared_peptides.R
\name{.handleSharedPeptides}
\alias{.handleSharedPeptides}
\title{Handle shared peptides.}
\usage{
.handleSharedPeptides(
  input,
  remove_shared = TRUE,
  protein_column = "ProteinName",
  peptide_column = "PeptideSequence"
)
}
\arguments{
\item{input}{data.table pre-processed by one of the .cleanRaw* functions.}

\item{remove_shared}{lgl, if TRUE, shared peptides will be removed}

\item{protein_column}{chr, name of the column with names of proteins.}

\item{peptide_column}{chr, name of the column with peptide sequences.}
}
\value{
data.table
}
\description{
Handle shared peptides.
}
\keyword{internal}
