% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils_dt_operations.R
\name{.fillValues}
\alias{.fillValues}
\title{Set column to a single value}
\usage{
.fillValues(input, fill_list)
}
\arguments{
\item{input}{data.table preprocessed by one of the \verb{cleanRaw*} functions.}

\item{fill_list}{named list, names correspond to column names, elements
to values that will be used in the columns.}
}
\value{
data.table
}
\description{
Set column to a single value
}
\keyword{internal}
