% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils_clean_features.R
\name{.handleSingleFeaturePerProtein}
\alias{.handleSingleFeaturePerProtein}
\title{Remove proteins only identified by a single feature}
\usage{
.handleSingleFeaturePerProtein(input, remove_single_feature)
}
\arguments{
\item{input}{\code{data.table} pre-processed by one of the .cleanRaw* functions.}

\item{remove_single_feature}{lgl, if TRUE, proteins with a single feature
will be removed.}
}
\value{
\code{data.table}
}
\description{
Remove proteins only identified by a single feature
}
\keyword{internal}
