% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils_checks.R
\name{.checkMSstatsParams}
\alias{.checkMSstatsParams}
\title{Check validity of parameters to the \code{MSstatsImport} function.}
\usage{
.checkMSstatsParams(
  input,
  annotation,
  feature_columns,
  remove_shared_peptides,
  remove_single_feature_proteins,
  feature_cleaning
)
}
\value{
none, throws an error if any of the assertions fail
}
\description{
Check validity of parameters to the \code{MSstatsImport} function.
}
\keyword{internal}
