% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/clean_Skyline.R
\name{.cleanRawSkyline}
\alias{.cleanRawSkyline}
\title{Clean raw data from Skyline}
\usage{
.cleanRawSkyline(msstats_object)
}
\arguments{
\item{msstats_object}{an object of class \code{MSstatsSpectroMineFiles}.}
}
\value{
data.table
}
\description{
Clean raw data from Skyline
}
\keyword{internal}
