% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/clean_Philosopher.R
\name{.cleanRawPhilosopher}
\alias{.cleanRawPhilosopher}
\title{Clean raw Philosopher files}
\usage{
.cleanRawPhilosopher(
  msstats_object,
  protein_id_col,
  peptide_id_col,
  channels,
  remove_shared_peptides
)
}
\arguments{
\item{msstats_object}{object of class MSstatsPhilosopherFiles}

\item{protein_id_col}{character name of a column that identifies proteins}

\item{peptide_id_col}{character name of a column that identifies peptides}

\item{channels}{character vector of channel labels}

\item{remove_shared_peptides}{logical, if TRUE, shared peptides will be
removed based on the IsUnique column from Philosopher output}
}
\value{
data.table
}
\description{
Clean raw Philosopher files
}
\keyword{internal}
