% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils_filtering.R
\name{.handleFiltering}
\alias{.handleFiltering}
\title{Handle PSM/proteins scores}
\usage{
.handleFiltering(input, score_filtering, exact_filtering, pattern_filtering)
}
\arguments{
\item{input}{\code{data.table} preprocessed by one of the .cleanRaw* functions.}

\item{score_filtering}{list of by-score filtering controls.}

\item{exact_filtering}{list of exact filtering controls.}

\item{pattern_filtering}{list of by-pattern filtering controls.}
}
\value{
data.table
}
\description{
Handle PSM/proteins scores
}
\keyword{internal}
