% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils_annotation.R
\name{.mergeAnnotation}
\alias{.mergeAnnotation}
\title{Merge annotation with feature data}
\usage{
.mergeAnnotation(input, annotation)
}
\arguments{
\item{annotation}{data.table with annotation}

\item{data.table}{preprocessed by one of the .cleanRaw functions.}
}
\value{
data.table
}
\description{
Merge annotation with feature data
}
\keyword{internal}
