% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils_balanced_design.R
\name{.fixMissingValues}
\alias{.fixMissingValues}
\title{Change labels for missing values}
\usage{
.fixMissingValues(input, fix_missing = NULL)
}
\arguments{
\item{input}{output of \code{MSstatsPreprocess}}

\item{fix_missing}{missing values can be labeled by \code{NA}, \code{0} or both.
If \code{NULL}, data were processed by Skyline, so missing values will be denoted
by both \code{NA} and \code{0}. If "na_to_zero", \code{NA} values will be replaced by \code{0}.
If "zero_to_na", \code{0} values will be replaced by \code{NA}}
}
\value{
data.table
}
\description{
Change labels for missing values
}
\keyword{internal}
