% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/clean_ProteomeDiscoverer.R
\name{.cleanRawPDMSstats}
\alias{.cleanRawPDMSstats}
\title{Clean raw PD output}
\usage{
.cleanRawPDMSstats(
  msstats_object,
  quantification_column,
  protein_id_column,
  sequence_column,
  remove_shared,
  run_column = "SpectrumFile"
)
}
\arguments{
\item{msstats_object}{an object of class \code{MSstatsSpectroMineFiles}.}

\item{quantification_column}{chr, name of a column used for quantification.}

\item{protein_id_column}{chr, name of a column with protein IDs.}

\item{sequence_column}{chr, name of a column with peptide sequences.}

\item{remove_shared}{lgl, if TRUE, shared peptides will be removed.}
}
\value{
data.table
}
\description{
Clean raw PD output
}
\keyword{internal}
