% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils_balanced_design.R
\name{.checkDuplicatedMeasurements}
\alias{.checkDuplicatedMeasurements}
\title{Check if there are duplicated measurements within run}
\usage{
.checkDuplicatedMeasurements(input)
}
\arguments{
\item{input}{output of \code{MSstatsPreprocess}}
}
\value{
character vector of feature labels
}
\description{
Check if there are duplicated measurements within run
}
\keyword{internal}
