% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils_clean_features.R
\name{.adjustIntensities}
\alias{.adjustIntensities}
\title{Fix invalid intensities: infinite to NA, between 0 and 1 to 0}
\usage{
.adjustIntensities(input)
}
\arguments{
\item{input}{data.table}
}
\value{
data.table
}
\description{
Fix invalid intensities: infinite to NA, between 0 and 1 to 0
}
\keyword{internal}
