% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils_clean_features.R
\name{.cleanByFeature}
\alias{.cleanByFeature}
\title{Perform by-feature operations.}
\usage{
.cleanByFeature(
  input,
  feature_columns,
  cleaning_control,
  anomaly_metrics = c()
)
}
\arguments{
\item{input}{\code{data.table} preprocessed by one of the cleanRaw* functions.}

\item{feature_columns}{character vector of names of columns that define features.}

\item{cleaning_control}{named list of two or three elements.
See the documentation for \code{MSstatsImport} for details.}

\item{anomaly_metrics}{character vector of quality metric column names to be
used as features in an anomaly detection model.}
}
\value{
\code{data.table}
}
\description{
Perform by-feature operations.
}
\keyword{internal}
