% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils_fractions.R
\name{.getOverlappingFeatures}
\alias{.getOverlappingFeatures}
\title{Get features that are overlapped among multiple runs}
\usage{
.getOverlappingFeatures(input)
}
\arguments{
\item{input}{data.table preprocessed by one of the .cleanRaw* functions and
merged with annotation.}
}
\value{
\code{data.table}
}
\description{
Get features that are overlapped among multiple runs
}
\keyword{internal}
