% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils_fractions.R
\name{.addFractions}
\alias{.addFractions}
\title{Add a Fraction column to the output of \code{MSstatsPreprocess}}
\usage{
.addFractions(input)
}
\arguments{
\item{input}{output of \code{MSstatsPreprocess}}
}
\value{
data.table
}
\description{
Add a Fraction column to the output of \code{MSstatsPreprocess}
}
\keyword{internal}
