% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils_checks.R
\name{.findAvailable}
\alias{.findAvailable}
\title{Select an available options from a set of possibilities}
\usage{
.findAvailable(possibilities, option_set, fall_back = NULL)
}
\arguments{
\item{possibilities}{possible legal values of a variable}

\item{option_set}{set of values that includes one of the \code{possibilities}}

\item{fall_back}{if there is none of the \code{possibilities} in \code{option_set},
or there are multiple hits, default to \code{fall_back}}
}
\value{
same as option_set, usually character
}
\description{
Select an available options from a set of possibilities
}
\keyword{internal}
