% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils_classes.R
\name{.MSstatsFormat}
\alias{.MSstatsFormat}
\title{Output format for further analysis by MSstats}
\usage{
.MSstatsFormat(input, anomaly_metrics = c())
}
\arguments{
\item{input}{data.table}

\item{anomaly_metrics}{character vector of quality metric column names to be used as features in an anomaly detection model}
}
\value{
object of class MSstatsValidated that inherits from data.frame
}
\description{
Output format for further analysis by MSstats
}
\keyword{internal}
