% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils_clean_features.R
\name{.aggregatePSMstoPeptideIons}
\alias{.aggregatePSMstoPeptideIons}
\title{Aggregate multiple PSMs to a single peptide ion.}
\usage{
.aggregatePSMstoPeptideIons(input, feature_columns, summary_function = sum)
}
\arguments{
\item{input}{data.table preprocessed by one of the cleanRaw* functions.}

\item{feature_columns}{chr, names of columns that define features.}

\item{summary_function}{function that will be used to aggregate intensities
if needed.}
}
\value{
data.table
}
\description{
Aggregate multiple PSMs to a single peptide ion.
}
\keyword{internal}
