% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils_shared_peptides.R
\name{.removeSharedPeptides}
\alias{.removeSharedPeptides}
\title{Remove peptides assigned to more than one protein.}
\usage{
.removeSharedPeptides(input, protein_column, peptide_column)
}
\arguments{
\item{input}{data.table pre-processed by one of the .cleanRaw* functions.}

\item{protein_column}{chr, name of the column with names of proteins.}

\item{peptide_column}{chr, name of the column with peptide sequences.}
}
\value{
data.table
}
\description{
Remove peptides assigned to more than one protein.
}
\keyword{internal}
