% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils_logging.R
\name{.consoleAppender}
\alias{.consoleAppender}
\title{Console appender: returns a function(level, ...) that writes one line to console}
\usage{
.consoleAppender()
}
\description{
Console appender: returns a function(level, ...) that writes one line to console
}
\keyword{internal}
