% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils_annotation.R
\name{.checkAnnotation}
\alias{.checkAnnotation}
\title{Check if the annotation is valid}
\usage{
.checkAnnotation(input, annotation)
}
\arguments{
\item{input}{data processed by the MSstatsClean}

\item{annotation}{annotation created by the MSstatsMakeAnnotation function}
}
\value{
TRUE invisibly if the annotation is correct, throws an error otherwise
}
\description{
Check if the annotation is valid
}
\keyword{internal}
