% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils_dt_operations.R
\name{.getChannelColumns}
\alias{.getChannelColumns}
\title{Get intensity columns from wide-format data}
\usage{
.getChannelColumns(col_names, ...)
}
\arguments{
\item{col_names}{names of columns, where some of the columns store intensity
value for different channels}

\item{...}{varying number of strings that define channel columns.}
}
\value{
character vector of column names that correspond to channel intensities
}
\description{
Get intensity columns from wide-format data
}
\keyword{internal}
