% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/clean_MaxQuant.R
\name{.cleanRawMaxQuant}
\alias{.cleanRawMaxQuant}
\title{Clean raw output from MaxQuant}
\usage{
.cleanRawMaxQuant(
  msstats_object,
  protein_id_col,
  remove_by_site = FALSE,
  channel_columns = "Reporterintensitycorrected"
)
}
\arguments{
\item{msstats_object}{object that inherits from MSstatsInputFiles class.}

\item{protein_id_col}{character, name of a column with names of proteins.}

\item{remove_by_site}{logical, if TRUE, proteins only identified by site will
be removed.}

\item{channel_columns}{character, regular expression that identifies channel columns
in TMT data.}
}
\value{
data.table
}
\description{
Clean raw output from MaxQuant
}
\keyword{internal}
