% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils_clean_features.R
\name{.filterFewMeasurements}
\alias{.filterFewMeasurements}
\title{Remove features with a small number of (non-missing) measurements across runs}
\usage{
.filterFewMeasurements(
  input,
  min_intensity,
  remove_few,
  feature_columns = NULL
)
}
\arguments{
\item{input}{\code{data.table} pre-processed by one of the .cleanRaw* functions.}

\item{min_intensity}{minimum intensity that will be considered non-missing.}

\item{remove_few}{logical, if TRUE, features that have less than three
measurements will be removed. If FALSE, only features with all missing runs
will be removed.}

\item{feature_columns}{chr, vector of names of columns that define features.}
}
\value{
data.table
}
\description{
Remove features with a small number of (non-missing) measurements across runs
}
\keyword{internal}
