% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils_filtering.R
\name{.filterManyColumns}
\alias{.filterManyColumns}
\title{Filter rows that contain specifed symbols in multiple columns.}
\usage{
.filterManyColumns(input, filter_columns, filter_symbols)
}
\arguments{
\item{input}{data.table preprocessed by one of the \verb{cleanRaw*} functions.}

\item{filter_columns}{chr, names of columns in which elements will be matched
and removed.}

\item{filter_symbols}{chr, vector of strings. Rows with corresponding elements
in \code{filter_columns} will be removed.}
}
\value{
data.table
}
\description{
Filter rows that contain specifed symbols in multiple columns.
}
\keyword{internal}
