% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils_fractions.R
\name{.checkMultiRun}
\alias{.checkMultiRun}
\title{Check if fractionation exists}
\usage{
.checkMultiRun(input)
}
\arguments{
\item{input}{output of \code{MSstatsPreprocess}}
}
\value{
list of two elements: \code{has_fractions} (logical) indicates if
fractions was detected in the \code{input} dataset, \code{is_risky} (logical)
indicates if there was a problem with detecting fractionation.
}
\description{
Check if fractionation exists
}
\keyword{internal}
