% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils_filtering.R
\name{.filterByPattern}
\alias{.filterByPattern}
\title{Handle filtering by pattern}
\usage{
.filterByPattern(input, col_name, patterns, filter, drop)
}
\arguments{
\item{input}{\code{data.table} preprocessed by one of the .cleanRaw* functions.}

\item{col_name}{chr, name of the column with peptide sequences.}

\item{patterns}{chr, regular expression - matching peptides will be
removed from the data.}

\item{filter}{lgl, if TRUE, peptides will be actually filtered.}

\item{drop}{lgl, if TRUE, the \code{column} will be dropped.}
}
\value{
data.table
}
\description{
Handle filtering by pattern
}
\keyword{internal}
