% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils_dt_operations.R
\name{.getDataTable}
\alias{.getDataTable}
\title{Read file from a provided path or convert given data.frame to data.table}
\usage{
.getDataTable(input, ...)
}
\arguments{
\item{input}{report from a signal processing tool or a path to it}

\item{...}{additional parameters for data.table::fread}
}
\value{
data.table
}
\description{
Read file from a provided path or convert given data.frame to data.table
}
\keyword{internal}
