% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/clean_Skyline.R
\name{.checkDDA}
\alias{.checkDDA}
\title{Check validity of DDA data}
\usage{
.checkDDA(input)
}
\arguments{
\item{input}{data.table preprocessed by one of the \verb{cleanRaw*} functions.}
}
\value{
logical

logical, TRUE means that the \code{input} dataset comes from a DDA experiment
}
\description{
Check validity of DDA data
}
\keyword{internal}
